#
# Cookbook:: gitlab-ci-runner
# Library:: cookbook_resource
#
# Copyright:: 2020, Ben Hughes <bmhughes@bmhughes.co.uk>, All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

module GitlabCiRunner
  module Cookbook
    # Helpers for cookbook resources
    module ResourceHelpers
      def config_resource_init
        config_resource_create unless config_resource_exist?
      end

      def hash_keys_string?(hash)
        raise ArgumentError, "Expected Hash, got #{hash.class}." unless hash.is_a?(Hash)

        hash.each_key { |k| return false unless k.is_a?(String) }
        hash.select { |_, v| v.is_a?(Hash) }.each_value { |v| return false unless hash_keys_string?(v) }

        log_chef(:debug, 'Hash key String check passed.')
        true
      end

      private

      def config_resource_exist?
        !find_resource!(:template, new_resource.config_file).nil?
      rescue Chef::Exceptions::ResourceNotFound
        false
      end

      def config_resource_create
        with_run_context :root do
          edit_resource(:chef_gem, 'toml-rb').compile_time(true)

          edit_resource(:template, new_resource.config_file) do
            source new_resource.template
            cookbook new_resource.cookbook

            owner new_resource.owner
            group new_resource.group
            mode new_resource.mode
            sensitive new_resource.sensitive

            variables['global'] = toml_load(new_resource.config_file).select { |k, _| !k.eql?('runners') }
            variables['runners'] = toml_load(new_resource.config_file).fetch('runners', [])

            helpers(GitlabCiRunner::Cookbook::CommonHelpers)
            helpers(GitlabCiRunner::Cookbook::TomlHelpers)

            action :nothing
            delayed_action :create
          end
        end
      end
    end
  end
end
