#
# Cookbook:: gitlab-ci-runner
# Resource:: global_config
#
# Copyright:: 2020, Ben Hughes <bmhughes@bmhughes.co.uk>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

include GitlabCiRunner::Cookbook::Helpers

property :config_file, String,
          default: '/etc/gitlab-runner/config.toml',
          description: 'Configuration file location'

property :cookbook, String,
          default: 'gitlab-ci-runner',
          description: 'Cookbook to source configuration file template from'

property :template, String,
          default: 'gitlab-runner/config.toml.erb',
          description: 'Template to use to generate the configuration file'

property :owner, String,
          default: lazy { default_gitlab_runner_user },
          description: 'Owner of the generated configuration file'

property :group, String,
          default: lazy { default_gitlab_runner_group },
          description: 'Group of the generated configuration file'

property :mode, String,
          default: '0600',
          description: 'Filemode of the generated configuration file'

property :sensitive, [true, false],
          default: true

property :concurrent, Integer

property :log_level, String

property :log_format, String

property :check_interval, Integer

property :sentry_dsn, [true, false]

property :listen_address, String

property :options, Hash

property :session_server, Hash

action_class do
  include GitlabCiRunner::Cookbook::ResourceHelpers
  include GitlabCiRunner::Cookbook::RunnerHelpers
end

action :set do
  config_resource_init

  global = {}

  %i(
    concurrent
    log_level
    log_format
    check_interval
    sentry_dsn
    listen_address
    session_server
  ).each do |key|
    next if new_resource.send(key).nil?

    global[key.to_s] = new_resource.send(key).dup
  end

  edit_resource(:template, new_resource.config_file) do
    variables['global'] = compact_hash(global)
  end
end
